# MOJIZA FRAMEWORK

- #### -version 0.0.1
***

`MOJIZA` — bu Python asosidagi zamonaviy, minimalistik va foydalanuvchi uchun qulay web framework. Bu framework orqali siz o'zingizning web sahifalaringizni oddiy, tushunarli va tez tarzda yaratishingiz mumkin.
***
![MOJIZA Banner](/STATIC/mojza.png) <!-- optional -->
***
## 🚀 Xususiyatlar

-  HTML elementlarini Python'da deklarativ tarzda yaratish
-  Zamonaviy "Dark mode" dizayn
-  Tilni almashtirish tugmasi orqali O‘zbek va Ingliz tillarida ishlash
-  Framework ichida tayyor `engine` tuzilmasi
-  Dynamic `data` dict orqali elementlar avlodan chiqariladi
-  Minimal frontend + backend birlashtirish imkoni
- ️ API tarzida ishlatish imkoniyati
-  Django bilan integratsiya qilish mumkin (view → url)

## 📂 Loyiha tuzilmasi

```bash
MOJIZA/
├── engine/
│   ├── server.py
│   ├── routing.py
│   ├── components.py
│   └── ...
├── static/
│   └── style.css
├── templates/
│   └── ...
├── app.py
└── README.md
```


loixa xali toliq bitrlmagan backend ustida hali ham ishlanmoqda!!